Index: pbx/pbx_spool.c
===================================================================
--- pbx/pbx_spool.c	(revision 78158)
+++ pbx/pbx_spool.c	(working copy)
@@ -68,18 +68,18 @@
 
 struct outgoing {
 	char fn[256];
-	/* Current number of retries */
+	/*! Current number of retries */
 	int retries;
-	/* Maximum number of retries permitted */
+	/*! Maximum number of retries permitted */
 	int maxretries;
-	/* How long to wait between retries (in seconds) */
+	/*! How long to wait between retries (in seconds) */
 	int retrytime;
-	/* How long to wait for an answer */
+	/*! How long to wait for an answer */
 	int waittime;
-	/* PID which is currently calling */
+	/*! PID which is currently calling */
 	long callingpid;
 	
-	/* What to connect to outgoing */
+	/*! What to connect to outgoing */
 	char tech[256];
 	char dest[256];
 	
@@ -96,16 +96,16 @@
 	char cid_num[256];
 	char cid_name[256];
 
-	/* account code */
+	/*! account code */
 	char account[AST_MAX_ACCOUNT_CODE];
 
-	/* Variables and Functions */
+	/*! Variables and Functions */
 	struct ast_variable *vars;
 	
-	/* Maximum length of call */
+	/*! Maximum length of call */
 	int maxlen;
 
-	/* options */
+	/*! options */
 	struct ast_flags options;
 };
 
Index: main/sha1.c
===================================================================
--- main/sha1.c	(revision 78158)
+++ main/sha1.c	(working copy)
@@ -1,6 +1,6 @@
-/*
+/*! \file
  *
- * Based on the RFC 3174
+ * \brief Based on the RFC 3174
  * 
  * Full Copyright Statement
  *
@@ -63,9 +63,7 @@
 
 #include "asterisk/sha1.h"
 
-/*
- *  Define the SHA1 circular left shift macro
- */
+/*! Define the SHA1 circular left shift macro */
 #define SHA1CircularShift(bits,word) \
 		         (((word) << (bits)) | ((word) >> (32-(bits))))
 
@@ -73,20 +71,12 @@
 void SHA1PadMessage(SHA1Context *);
 void SHA1ProcessMessageBlock(SHA1Context *);
 
-/*
- *  SHA1Reset
- *
- *  Description:
- *	  This function will initialize the SHA1Context in preparation
- *	  for computing a new SHA1 message digest.
- *
- *  Parameters:
- *	  context: [in/out]
- *		   The context to reset.
- *
- *  Returns:
- *	  sha Error Code.
- *
+/*!
+ * \brief SHA1Reset
+ * \param context the context to be reset
+ * This function will initialize the SHA1Context in preparation
+ * for computing a new SHA1 message digest.
+ * \return sha Error Code.
  */
 int SHA1Reset(SHA1Context *context)
 {
@@ -110,24 +100,15 @@
 	return shaSuccess;
 }
 
-/*
- *  SHA1Result
- *
- *  Description:
- *	  This function will return the 160-bit message digest into the
- *	  Message_Digest array  provided by the caller.
- *	  NOTE: The first octet of hash is stored in the 0th element,
- *		     the last octet of hash in the 19th element.
- *
- *  Parameters:
- *	  context: [in/out]
- *		   The context to use to calculate the SHA-1 hash.
- *	  Message_Digest: [out]
- *		   Where the digest is returned.
- *
- *  Returns:
- *	  sha Error Code.
- *
+/*!
+ * \brief SHA1Result
+ * \param context [in/out] The context to use to calculate the SHA-1 hash.
+ * \param Message_Digest [out] Where the digest is returned.
+ *  This function will return the 160-bit message digest into the
+ *  Message_Digest array  provided by the caller.
+ * \note The first octet of hash is stored in the 0th element, 
+ * 	the last octet of hash in the 19th element.
+ * \return sha Error Code.
  */
 int SHA1Result( SHA1Context *context,
 		         uint8_t Message_Digest[SHA1HashSize])
@@ -160,25 +141,15 @@
 	return shaSuccess;
 }
 
-/*
- *  SHA1Input
- *
- *  Description:
- *	  This function accepts an array of octets as the next portion
- *	  of the message.
- *
- *  Parameters:
- *	  context: [in/out]
- *		   The SHA context to update
- *	  message_array: [in]
- *		   An array of characters representing the next portion of
+/*!
+ *  \brief SHA1Input
+ * \param context [in/out] The SHA context to update
+ * \param message_array [in] An array of characters representing the next portion of
  *		   the message.
- *	  length: [in]
- *		   The length of the message in message_array
- *
- *  Returns:
- *	  sha Error Code.
- *
+ * \param length [in] The length of the message in message_array
+ *  This function accepts an array of octets as the next portion
+ *  of the message.
+ * \return sha Error Code.
  */
 int SHA1Input(SHA1Context *context, const uint8_t *message_array, unsigned length)
 {
@@ -221,25 +192,13 @@
 	return shaSuccess;
 }
 
-/*
- *  SHA1ProcessMessageBlock
- *
- *  Description:
- *	  This function will process the next 512 bits of the message
- *	  stored in the Message_Block array.
- *
- *  Parameters:
- *	  None.
- *
- *  Returns:
- *	  Nothing.
- *
- *  Comments:
- *	  Many of the variable names in this code, especially the
+/*!
+ * \brief Process the next 512 bits of the message stored in the Message_Block array.
+ * \param context [in/out] The SHA context to update
+ * \note  Many of the variable names in this code, especially the
  *	  single character names, were used because those were the
  *	  names used in the publication.
- *
- *
+ * \returns nothing.
  */
 void SHA1ProcessMessageBlock(SHA1Context *context)
 {
@@ -320,27 +279,20 @@
 }
 
 
-/*
- *  SHA1PadMessage
+/*!
+ * \brief Pad message to be 512 bits.
+ * \param context [in/out]  The context to pad
+ * 
+ * According to the standard, the message must be padded to an even
+ *  512 bits.  The first padding bit must be a '1'.  The last 64
+ *  bits represent the length of the original message.  All bits in
+ *  between should be 0.  This function will pad the message
+ *  according to those rules by filling the Message_Block array
+ *  accordingly.  It will also call the ProcessMessageBlock function
+ *  provided appropriately.  When it returns, it can be assumed that
+ *  the message digest has been computed.
  *
- *  Description:
- *	  According to the standard, the message must be padded to an even
- *	  512 bits.  The first padding bit must be a '1'.  The last 64
- *	  bits represent the length of the original message.  All bits in
- *	  between should be 0.  This function will pad the message
- *	  according to those rules by filling the Message_Block array
- *	  accordingly.  It will also call the ProcessMessageBlock function
- *	  provided appropriately.  When it returns, it can be assumed that
- *	  the message digest has been computed.
- *
- *  Parameters:
- *	  context: [in/out]
- *		   The context to pad
- *	  ProcessMessageBlock: [in]
- *		   The appropriate SHA*ProcessMessageBlock function
- *  Returns:
- *	  Nothing.
- *
+ * \returns nothing.
  */
 
 void SHA1PadMessage(SHA1Context *context)
Index: res/res_crypto.c
===================================================================
--- res/res_crypto.c	(revision 78158)
+++ res/res_crypto.c	(working copy)
@@ -102,6 +102,16 @@
  * \param userdata
  * \return length of string,-1 on failure
 */
+
+
+/*!
+ * \brief setting of priv key
+ * \param buf
+ * \param size
+ * \param rwflag
+ * \param userdata
+ * \return length of string,-1 on failure
+*/
 static int pw_cb(char *buf, int size, int rwflag, void *userdata)
 {
 	struct ast_key *key = (struct ast_key *)userdata;
@@ -283,6 +293,10 @@
  * \brief signs outgoing message with public key
  * \see ast_sign_bin
 */
+/*!
+ * \brief signs outgoing message with public key
+ * \see ast_sign_bin
+*/
 static int __ast_sign_bin(struct ast_key *key, const char *msg, int msglen, unsigned char *dsig)
 {
 	unsigned char digest[20];
Index: utils/smsq.c
===================================================================
--- utils/smsq.c	(revision 78158)
+++ utils/smsq.c	(working copy)
@@ -38,9 +38,11 @@
 #endif
 
 
-/* reads next USC character from null terminated UTF-8 string and advanced pointer */
-/* for non valid UTF-8 sequences, returns character as is */
-/* Does not advance pointer for null termination */
+/*!
+ * \brief reads next USC character from null terminated UTF-8 string and advanced pointer
+ * for non valid UTF-8 sequences.
+ * \return character as is Does \b NOT advance pointer for null termination 
+*/
 static int utf8decode (unsigned char **pp)
 {
    unsigned char *p = *pp;
@@ -90,8 +92,13 @@
    return *p;                   /* not sensible */
 }
 
-/* check for any queued messages in specific queue (queue="" means any queue) */
-/* returns 0 if nothing queued, 1 if queued and outgoing set up OK, 2 of outgoing exists */
+/*! 
+ * \brief check for any queued messages in specific queue (queue="" means any queue)
+ * \param dir,queue,subaddress,channel,callerid,wait,delay,retries,concurrent
+ * \retval 0 if nothing queued
+ * \retval 1 if queued and outgoing set up OK
+ * \retval 2 of outgoing exists 
+*/
 static char txqcheck (char *dir, char *queue, char subaddress, char *channel, char *callerid, int wait, int delay, int retries, int concurrent)
 {
    char ogname[100],
@@ -186,7 +193,10 @@
    return 2;
 }
 
-/* Process received queue entries and run through a process, setting environment variables */
+/*! 
+ * \brief Process received queue entries
+ * Run through a process, setting environment variables
+*/
 static void rxqcheck (char *dir, char *queue, char *process)
 {
    char *p;
